mailr9274 - /branches/bmrb/bmrblib/kinetics/general_relaxation.py


Others Months | Index by Date | Thread Index
>>   [Date Prev] [Date Next] [Thread Prev] [Thread Next]

Header


Content

Posted by edward on July 22, 2009 - 16:16:
Author: bugman
Date: Wed Jul 22 15:54:49 2009
New Revision: 9274

URL: http://svn.gna.org/viewcvs/relax?rev=9274&view=rev
Log:
Created the bmrblib.kinetics.general_relaxation module.

Much work is still to be done.


Added:
    branches/bmrb/bmrblib/kinetics/general_relaxation.py
      - copied, changed from r9271, 
branches/bmrb/bmrblib/kinetics/heteronucl_T1_relaxation.py

Copied: branches/bmrb/bmrblib/kinetics/general_relaxation.py (from r9271, 
branches/bmrb/bmrblib/kinetics/heteronucl_T1_relaxation.py)
URL: 
http://svn.gna.org/viewcvs/relax/branches/bmrb/bmrblib/kinetics/general_relaxation.py?p2=branches/bmrb/bmrblib/kinetics/general_relaxation.py&p1=branches/bmrb/bmrblib/kinetics/heteronucl_T1_relaxation.py&r1=9271&r2=9274&rev=9274&view=diff
==============================================================================
--- branches/bmrb/bmrblib/kinetics/heteronucl_T1_relaxation.py (original)
+++ branches/bmrb/bmrblib/kinetics/general_relaxation.py Wed Jul 22 15:54:49 
2009
@@ -21,7 +21,7 @@
 
###############################################################################
 
 # Module docstring.
 """The Heteronuclear T1 data saveframe category.
 
 For example, see 
http://www.bmrb.wisc.edu/dictionary/3.1html/SaveFramePage.html#heteronucl_T1_relaxation.
 """
@@ -34,8 +34,8 @@
 from pystarlib.TagTable import TagTable
 
 
-class HeteronuclT1Saveframe(RelaxSaveframe):
-    """The Heteronuclear T1 data saveframe class."""
+class GeneralRelaxationSaveframe(RelaxSaveframe):
+    """The General Relaxation data saveframe class."""
 
     # Saveframe variables.
     label = 'T1'
@@ -119,24 +119,24 @@
         """Create the tag categories."""
 
         # The tag category objects.
-        self.heteronuclRxlist = HeteronuclT1List(self)
-        self.heteronuclRxexperiment = HeteronuclT1Experiment(self)
-        self.heteronuclRxsoftware = HeteronuclT1Software(self)
+        self.heteronuclRxlist = GeneralRelaxationList(self)
+        self.heteronuclRxexperiment = GeneralRelaxationExperiment(self)
+        self.heteronuclRxsoftware = GeneralRelaxationSoftware(self)
         self.Rx = T1(self)
 
 
-class HeteronuclT1List(HeteronuclRxList):
-    """Base class for the HeteronuclT1List tag category."""
+class GeneralRelaxationList(HeteronuclRxList):
+    """Base class for the GeneralRelaxationList tag category."""
 
     def create(self):
         """Create the HeteronuclT1List tag category."""
 
         # The save frame category.
         self.sf.frame.tagtables.append(self.create_tag_table([['SfCategory', 
'cat_name']], free=True))
 
         # T1 ID number.
-        if self.tag_names.has_key('HeteronuclT1ListID'):
-            self.sf.frame.tagtables.append(TagTable(free=True, 
tagnames=[self.tag_names_full['HeteronuclT1ListID']], 
tagvalues=[[str(self.sf.r1_inc)]]))
+        if self.tag_names.has_key('GeneralRelaxationListID'):
+            self.sf.frame.tagtables.append(TagTable(free=True, 
tagnames=[self.tag_names_full['GeneralRelaxationListID']], 
tagvalues=[[str(self.sf.r1_inc)]]))
 
         # Sample info.
         self.sf.frame.tagtables.append(TagTable(free=True, 
tagnames=[self.tag_names_full['SampleConditionListLabel']], 
tagvalues=[['$conditions_1']]))
@@ -171,11 +171,11 @@
 
 
 
-class HeteronuclT1Experiment(TagCategory):
-    """Base class for the HeteronuclT1Experiment tag category."""
+class GeneralRelaxationExperiment(TagCategory):
+    """Base class for the GeneralRelaxationExperiment tag category."""
 
     def create(self, frame=None):
         """Create the HeteronuclT1Experiment tag category."""
 
         # Sample info.
         self.sf.frame.tagtables.append(TagTable(free=True, 
tagnames=[self.tag_names_full['SampleLabel']], tagvalues=[['$sample_1']]))
@@ -197,11 +197,11 @@
         self.tag_names['SampleLabel'] = 'Sample_label'
 
 
-class HeteronuclT1Software(TagCategory):
-    """Base class for the HeteronuclT1Software tag category."""
+class GeneralRelaxationSoftware(TagCategory):
+    """Base class for the GeneralRelaxationSoftware tag category."""
 
     def create(self):
         """Create the HeteronuclT1Software tag category."""
 
 
 class T1(Rx):
@@ -21,7 +21,7 @@
 
 # Module docstring.
-"""The Heteronuclear T1 data saveframe category.
+"""The General Relaxation data saveframe category.
 
 For example, see 
@@ -119,24 +119,24 @@
 
     def create(self):
-        """Create the HeteronuclT1List tag category."""
+        """Create the GeneralRelaxationList tag category."""
 
         # The save frame category.
@@ -171,11 +171,11 @@
 
     def create(self, frame=None):
-        """Create the HeteronuclT1Experiment tag category."""
+        """Create the GeneralRelaxationExperiment tag category."""
 
         # Sample info.
@@ -197,11 +197,11 @@
 
     def create(self):
-        """Create the HeteronuclT1Software tag category."""
+        """Create the GeneralRelaxationSoftware tag category."""
 
 




Related Messages


Powered by MHonArc, Updated Wed Jul 22 16:20:04 2009